@@ -1,4 +1,4 @@
-from .rest import RestClient
+from ..rest import RestClient
 
 
 class Tenants(object):
@@ -16,15 +16,30 @@ class Tenants(object):
             connect and read timeout. Pass a tuple to specify
             both values separately or a float to set both to it.
             (defaults to 5.0 for both)
+
+        rest_options (RestClientOptions): Pass an instance of
+            RestClientOptions to configure additional RestClient
+            options, such as rate-limit retries.
+            (defaults to None)
     """
 
-    def __init__(self, domain, token, telemetry=True, timeout=5.0, protocol="https"):
+    def __init__(
+        self,
+        domain,
+        token,
+        telemetry=True,
+        timeout=5.0,
+        protocol="https",
+        rest_options=None,
+    ):
         self.domain = domain
         self.protocol = protocol
-        self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
+        self.client = RestClient(
+            jwt=token, telemetry=telemetry, timeout=timeout, options=rest_options
+        )
 
     def _url(self):
-        return '{}://{}/api/v2/tenants/settings'.format(self.protocol, self.domain)
+        return "{}://{}/api/v2/tenants/settings".format(self.protocol, self.domain)
 
     def get(self, fields=None, include_fields=True):
         """Get tenant settings.
@@ -36,12 +51,14 @@ class Tenants(object):
 
            include_fields (bool, optional): True if the fields specified are
               to be included in the result, False otherwise. Defaults to True.
-              
+
         See: https://auth0.com/docs/api/management/v2#!/Tenants/get_settings
         """
 
-        params = {'fields': fields and ','.join(fields) or None,
-                  'include_fields': str(include_fields).lower()}
+        params = {
+            "fields": fields and ",".join(fields) or None,
+            "include_fields": str(include_fields).lower(),
+        }
 
         return self.client.get(self._url(), params=params)
 
