@@ -1,7 +1,8 @@
 import unittest
 
-from ...management.auth0 import Auth0
 from ...management.actions import Actions
+from ...management.attack_protection import AttackProtection
+from ...management.auth0 import Auth0
 from ...management.blacklists import Blacklists
 from ...management.client_grants import ClientGrants
 from ...management.clients import Clients
@@ -28,6 +29,7 @@ from ...management.tickets import Tickets
 from ...management.user_blocks import UserBlocks
 from ...management.users import Users
 from ...management.users_by_email import UsersByEmail
+from ...rest import RestClientOptions
 
 
 class TestAuth0(unittest.TestCase):
@@ -36,9 +38,12 @@ class TestAuth0(unittest.TestCase):
         self.token = "a-token"
         self.a0 = Auth0(self.domain, self.token)
 
-    def test_blacklists(self):
+    def test_actions(self):
         self.assertIsInstance(self.a0.actions, Actions)
 
+    def test_attack_protection(self):
+        self.assertIsInstance(self.a0.attack_protection, AttackProtection)
+
     def test_blacklists(self):
         self.assertIsInstance(self.a0.blacklists, Blacklists)
 
@@ -116,3 +121,8 @@ class TestAuth0(unittest.TestCase):
 
     def test_users(self):
         self.assertIsInstance(self.a0.users, Users)
+
+    def test_args(self):
+        rest_options = RestClientOptions(retries=99)
+        auth0 = Auth0(self.domain, self.token, rest_options=rest_options)
+        self.assertEqual(auth0.users.client.options.retries, 99)
